@@ -9,32 +9,40 @@ class BoseRadio1: public PIRKeysetMetaData
 {
 public:
   BoseRadio1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class BoseRadio2: public PIRKeysetMetaData
 {
 public:
   BoseRadio2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class BoseRadio3: public PIRKeysetMetaData
 {
 public:
   BoseRadio3(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class BoseHomeTheater1: public PIRKeysetMetaData
 {
 public:
   BoseHomeTheater1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // BOSE_H
