@@ -9,8 +9,10 @@ class SonyTV1: public PIRKeysetMetaData
 {
 public:
   SonyTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -18,8 +20,10 @@ class SonyTV1a: public SonyTV1
 {
 public:
   SonyTV1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -27,8 +31,10 @@ class SonyTV1b: public SonyTV1a
 {
 public:
   SonyTV1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -36,8 +42,10 @@ class SonyTV1c: public SonyTV1
 {
 public:
   SonyTV1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -45,8 +53,10 @@ class SonyAmp1: public PIRKeysetMetaData
 {
 public:
   SonyAmp1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -54,8 +64,10 @@ class SonyAmp2: public PIRKeysetMetaData
 {
 public:
   SonyAmp2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -63,8 +75,10 @@ class SonyAudio1: public PIRKeysetMetaData
 {
 public:
   SonyAudio1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -72,8 +86,10 @@ class SonyAudio1a: public SonyAudio1
 {
 public:
   SonyAudio1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -81,8 +97,10 @@ class SonyDAT1: public PIRKeysetMetaData
 {
 public:
   SonyDAT1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -90,8 +108,10 @@ class SonyDVD1: public PIRKeysetMetaData
 {
 public:
   SonyDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -99,8 +119,10 @@ class SonyDVD1a: public SonyDVD1
 {
 public:
   SonyDVD1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -108,8 +130,10 @@ class SonyDVD1b: public SonyDVD1
 {
 public:
   SonyDVD1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -117,8 +141,10 @@ class SonyDVD1c: public SonyDVD1
 {
 public:
   SonyDVD1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -126,8 +152,10 @@ class SonyVCR1: public PIRKeysetMetaData
 {
 public:
   SonyVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -135,8 +163,10 @@ class SonyVCR1a: public SonyVCR1
 {
 public:
   SonyVCR1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -144,8 +174,10 @@ class SonyVCR1b: public SonyVCR1a
 {
 public:
   SonyVCR1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 
@@ -153,8 +185,10 @@ class SonyReceiver1: public PIRKeysetMetaData
 {
 public:
   SonyReceiver1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // SONY_H
